package com.css.simulation.resource.model.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.model.ConfigPageParam;
import api.common.pojo.po.model.ConfigPO;
import api.common.pojo.po.model.ConfigSensorPO;
import api.common.pojo.vo.model.ConfigSensorVO;
import api.common.pojo.vo.model.ConfigVO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.common.utils.PageUtil;
import com.css.simulation.resource.model.mapper.CameraMapper;
import com.css.simulation.resource.model.mapper.ConfigMapper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

@Service
public class ConfigService {

    @Autowired
    ConfigMapper configMapper;

    public PageInfo<ConfigVO> getConfigPageList(ConfigPageParam pageParam) {
        PageUtil.setPageInfo(pageParam);
        pageParam.setCreateUserId(AuthUtil.getCurrentUserId());
        if(DictConstants.YES.equals(pageParam.getShare())){//公有查询去掉创建人id条件
            pageParam.setCreateUserId(null);
        }
        List<ConfigVO> list = configMapper.getConfigPageList(pageParam);
        return new PageInfo<>(list);
    }

    public ConfigVO getConfigInfo(ConfigPageParam pageParam) {
        ConfigVO ConfigvehicleVO = configMapper.getConfigInfo(pageParam);
        List<ConfigSensorVO> configSensors = configMapper.getConfigSensors(pageParam);
        ConfigvehicleVO.setConfigSensors(configSensors);
        return ConfigvehicleVO;
    }

    public ConfigPO saveConfig(ConfigVO configVO) {
        //构建主表对象
        ConfigPO configPO = new ConfigPO();
        String currentUserId = AuthUtil.getCurrentUserId();
        Timestamp currentTime = TimeUtil.getNowForMysql();
        ObjectUtil.voToPo(configVO,configPO);
        configPO.setCreateUserId(currentUserId);
        configPO.setCreateTime(currentTime);
        configPO.setModifyUserId(currentUserId);
        configPO.setModifyTime(currentTime);
        configPO.setIsDeleted(DictConstants.NO);
        //单独处理配置描述
        configPO.setDescription(configVO.getConfigDescription());
        //名称校验
        List<ConfigVO> list = configMapper.checkConfigName(configPO);
        if(ObjectUtil.isNotNull(list)){
            configPO.setId(null);
            return configPO;
        }
        //主表主键
        String configId = configPO.getId();
        if(ObjectUtil.isNull(configId)){//新增
            configId = StringUtil.getRandomUUID();
            configPO.setId(configId);
            configPO.setConfigCode(StringUtil.getRandomCode());
            configPO.setShare(DictConstants.NO);//私有
            configMapper.insertConfig(configPO);
        }else{//修改
            configMapper.updateConfig(configPO);
        }
        //删除子表旧数据
        configMapper.delConfigSensors(configPO);
        //构建字表新数据
        List<ConfigSensorVO> configSensorVOs = configVO.getConfigSensors();
        List<ConfigSensorPO> configSensorPOs = new ArrayList<>();
        if(ObjectUtil.isNotNull(configSensorVOs)){
            configSensorVOs.forEach(vo -> {
                ConfigSensorPO po = new ConfigSensorPO();
                ObjectUtil.voToPo(vo,po);
                po.setId(StringUtil.getRandomUUID());
                //子表外键
                po.setConfigId(configPO.getId());
                po.setCreateUserId(currentUserId);
                po.setCreateTime(currentTime);
                po.setModifyUserId(currentUserId);
                po.setModifyTime(currentTime);
                po.setIsDeleted(DictConstants.NO);
                configSensorPOs.add(po);
            });
        }
        if(ObjectUtil.isNotNull(configSensorPOs)){
            configMapper.insertConfigSensors(configSensorPOs);
        }
        return configPO;
    }

    public int delConfigById(ConfigVO vo) {
        ConfigPO po = new ConfigPO();
        ObjectUtil.voToPo(vo,po);
        po.setIsDeleted(DictConstants.YES);
        po.setModifyUserId(AuthUtil.getCurrentUserId());
        po.setModifyTime(TimeUtil.getNowForMysql());
        int i = configMapper.delConfigById(po);
        return i;
    }
}
